@@ -18,14 +18,15 @@ $languageStrings = array(
 	'LBL_DESCRIPTION' => 'Description',
 	'LBL_SUBJECT' => 'Subject',
 	'LBL_GENERAL_FIELDS' => 'General Fields',
-	'LBL_SELECT_FIELD_TYPE' => 'Válassza ki a Modul & Field',
-	'LBL_MODULE_NAME' => 'Modul neve',
+	'LBL_SELECT_FIELD_TYPE' => 'Selecteer Module & Field',
+	'LBL_MODULE_NAME' => 'Module Name',
 	'LBL_EMAIL_TEMPLATE_DESCRIPTION'=>'Manage templates for E-Mail module',
-	'LBL_NO_PERMISSIONS_TO_DELETE_SYSTEM_TEMPLATE' => 'Nem Engedélyek törölni Rendszer Sablon',
-	'LBL_RECORD_ID'                => 'Rekordazonosja'         , 
+	'LBL_NO_PERMISSIONS_TO_DELETE_SYSTEM_TEMPLATE' => 'Geen Machtigingen naar Verwijderen System Template',
+	'LBL_RECORD_ID'                => 'Record-ID'                   , 
+	
 );
 
 $jsLanguageStrings = array(
-    'LBL_CUTOMER_LOGIN_DETAILS_TEMPLATE_DELETE_MESSAGE' => 'Ön nem fogja tudni elküldeni az ügyfél portál bejelentkezési adatait a kapcsolatot, ha törli "Vásárló Belépés Részletek" sablont. Szeretné folytatni?',
-	'JS_REQUIRED_FIELD' => '* Message szükséges',
-);
+    'LBL_CUTOMER_LOGIN_DETAILS_TEMPLATE_DELETE_MESSAGE' => 'U zult niet in staat zijn om de customer portal login gegevens te sturen naar de contactpersoon als u "Klanten Login Gegevens" sjabloon verwijderen. Wilt u doorgaan?',
+	'JS_REQUIRED_FIELD' => '* Bericht is vereist',
+);
\ No newline at end of file
