@@ -15,7 +15,7 @@ $languageStrings = array(
 	'Module'                       => 'Module'                      , // TODO: Review
 	'Return Url'                   => 'Return Url'                  , // TODO: Review
 	'Post Url'                     => 'Post Url'                    , // TODO: Review
-    'Captcha Enabled'              => 'Captcha activé'              ,
+    'Captcha Enabled'              => 'Captcha ingeschakeld'        ,
 	'SINGLE_Webforms'              => 'Webform'                     , // TODO: Review
 	'LBL_SHOW_FORM'                => 'Show Form'                   , // TODO: Review
 	'LBL_DUPLICATES_EXIST'         => 'Webform Name already exists' , // TODO: Review
@@ -31,35 +31,35 @@ $languageStrings = array(
 	'LBL_EMBED_THE_FOLLOWING_FORM_IN_YOUR_WEBSITE' => 'Embed the following form in your website', // TODO: Review
 	'LBL_SELECT_VALUE'             => 'Select Value'                , // TODO: Review
 	'LBL_LABEL'                    => 'label'                       , // TODO: Review
-	'LBL_SAVE_FIELDS_ORDER' => 'Enregistrer ordre des champs', 
-	'LBL_HIDDEN' => 'Caché',
-	'LBL_ENABLE_TARGET_MODULES_FOR_WEBFORM' => 'Activer modules cibles pour formulaire en ligne',
-	'LBL_ASSIGN_USERS' => 'Affectation de l\'utilisateur',
-    'LBL_ASSIGN_ROUND_ROBIN' => 'Affecter des utilisateurs en Round Robin',
-    'LBL_ROUNDROBIN_USERS_LIST' => 'Round Robin Liste des utilisateurs',
+	'LBL_SAVE_FIELDS_ORDER' => 'Sparen velden bestellen', 
+	'LBL_HIDDEN' => 'Verborgen',
+	'LBL_ENABLE_TARGET_MODULES_FOR_WEBFORM' => 'Enable Target modules voor webformulier',
+	'LBL_ASSIGN_USERS' => 'Gebruiker Assignment',
+    'LBL_ASSIGN_ROUND_ROBIN' => 'Gebruikers toewijzen In Round Robin',
+    'LBL_ROUNDROBIN_USERS_LIST' => 'Round Robin Gebruikers Lijst',
 
-  'LBL_ADD_RECORD' => 'Ajouter Webform',
+  'LBL_ADD_RECORD' => 'Toevoegen Webformulier',
 
-	'LBL_UPLOAD_DOCUMENTS' => 'Documents Téléchargement',
-	'LBL_ADD_FILE_FIELD' => 'File Upload champs',
-	'LBL_FIELD_LABEL' => 'Titre du document',
-	'LBL_FILE_FIELD_INFO' => 'Pour chaque fichier téléchargé du web forment un nouveau document est créé avec le fichier joint. Le document est également lié à ce nouveau%s.',
-	'LBL_NO_FILE_FIELD' => 'Aucun champ de fichier ajouté.',
-	'LBL_COPY_TO_CLIPBOARD' => 'Copier dans le presse-papier',
+	'LBL_UPLOAD_DOCUMENTS' => 'Upload Documents',
+	'LBL_ADD_FILE_FIELD' => 'Bestanden uploaden Field',
+	'LBL_FIELD_LABEL' => 'Document titel',
+	'LBL_FILE_FIELD_INFO' => 'Voor elk bestand geüpload van web vormen een nieuw document wordt gemaakt met het bijgevoegde bestand. Het document is ook gekoppeld aan deze nieuw gecreëerde%s.',
+	'LBL_NO_FILE_FIELD' => 'Geen bestand velden toegevoegd.',
+	'LBL_COPY_TO_CLIPBOARD' => 'Kopieer naar klembord',
 );
 $jsLanguageStrings = array(
 	'JS_WEBFORM_DELETED_SUCCESSFULLY' => 'Webform deleted successfully', // TODO: Review
 	'JS_LOADING_TARGET_MODULE_FIELDS' => 'Loadding Target Module Fields', // TODO: Review
 	'JS_SELECT_VALUE'              => 'Select Vlaue'                , // TODO: Review
-	'JS_MANDATORY_FIELDS_WITHOUT_OVERRIDE_VALUE_CANT_BE_HIDDEN' => 'Les champs obligatoires sans valeurs de remplacement ne peux pas être cachés',
-	'JS_REFERENCE_FIELDS_CANT_BE_MANDATORY_WITHOUT_OVERRIDE_VALUE' => 'champs de référence ne peux pas être obligatoire sans valeur de remplacement',
-	'JS_TYPE_TO_SEARCH' => 'Tapez à la recherche',
-	"JS_WEBFORM_WITH_THIS_NAME_ALREADY_EXISTS" => 'Webform avec ce nom existe déjà',
+	'JS_MANDATORY_FIELDS_WITHOUT_OVERRIDE_VALUE_CANT_BE_HIDDEN' => 'Verplichte velden zonder voorrang boven de waarden niet kan worden verborgen',
+	'JS_REFERENCE_FIELDS_CANT_BE_MANDATORY_WITHOUT_OVERRIDE_VALUE' => 'Referentievelden cant verplicht zijn zonder override waarde',
+	'JS_TYPE_TO_SEARCH' => 'Typ om te zoeken',
+	"JS_WEBFORM_WITH_THIS_NAME_ALREADY_EXISTS" => 'Webformulier met deze naam bestaat',
 
-  'JS_SELECT_AN_OPTION' => 'Sélectionnez une Option',
-  'JS_LABEL' => 'étiquette',
+  'JS_SELECT_AN_OPTION' => 'Selecteer een Optie',
+  'JS_LABEL' => 'label',
 
-	'JS_MAX_FILE_FIELDS_LIMIT' => 'Maximum vous pouvez ajouter des champs de fichiers%.',
-	'JS_COPIED_SUCCESSFULLY' => 'Copié avec succès.',
-	'JS_COPY_FAILED' => "Échec de la copie. S'il vous plaît copier manuellement.",
+	'JS_MAX_FILE_FIELDS_LIMIT' => 'Maximaal kun je%s bestand velden toe te voegen.',
+	'JS_COPIED_SUCCESSFULLY' => 'gekopieerd.',
+	'JS_COPY_FAILED' => 'Kopiëren mislukt. Gelieve handmatig te kopiëren.',
 );
\ No newline at end of file
