@@ -352,21 +352,21 @@ function isPermitted($module,$actionname,$record_id='')
 			}
 		}
 		//Checking for vtiger_tab permission
-		if($profileTabsPermission[$tabid] !=0)
+		if(isset($profileTabsPermission[$tabid]) && $profileTabsPermission[$tabid] !=0)
 		{
 			$permission = "no";
 			$log->debug("Exiting isPermitted method ...");
 			return $permission;
 		}
 		//Checking for Action Permission
-		if(strlen($profileActionPermission[$tabid][$actionid]) <  1 && $profileActionPermission[$tabid][$actionid] == '')
+		if(isset($profileActionPermission[$tabid][$actionid]) && strlen($profileActionPermission[$tabid][$actionid]) <  1 && $profileActionPermission[$tabid][$actionid] == '')
 		{
 			$permission = "yes";
 			$log->debug("Exiting isPermitted method ...");
 			return $permission;
 		}
 
-		if($profileActionPermission[$tabid][$actionid] != 0 && $profileActionPermission[$tabid][$actionid] != '')
+		if(isset($profileActionPermission[$tabid][$actionid]) && $profileActionPermission[$tabid][$actionid] != 0 && $profileActionPermission[$tabid][$actionid] != '')
 		{
 			$permission = "no";
 			$log->debug("Exiting isPermitted method ...");
@@ -656,7 +656,7 @@ function isReadPermittedBySharing($module,$tabid,$actionid,$record_id)
 		foreach($relatedModuleArray as $parModId)
 		{
 			$parRecordOwner=getParentRecordOwner($tabid,$parModId,$record_id);
-			if(sizeof($parRecordOwner) > 0)
+			if(php7_sizeof($parRecordOwner) > 0)
 			{
 				$parModName=getTabname($parModId);
 				$rel_var=$parModName."_".$module."_share_read_permission";
@@ -796,7 +796,7 @@ function isReadWritePermittedBySharing($module,$tabid,$actionid,$record_id)
 		foreach($relatedModuleArray as $parModId)
 		{
 			$parRecordOwner=getParentRecordOwner($tabid,$parModId,$record_id);
-			if(sizeof($parRecordOwner) > 0)
+			if(php7_sizeof($parRecordOwner) > 0)
 			{
 				$parModName=getTabname($parModId);
 				$rel_var=$parModName."_".$module."_share_write_permission";
@@ -1054,8 +1054,9 @@ function getRoleInformation($roleid)
 	$rolename=$adb->query_result($result,0,'rolename');
 	$parentrole=$adb->query_result($result,0,'parentrole');
 	$roledepth=$adb->query_result($result,0,'depth');
-	$parentRoleArr=explode('::',$parentrole);
-	$immediateParent=$parentRoleArr[sizeof($parentRoleArr)-2];
+	$parentRoleArr=explode('::',$parentrole ? $parentrole:'');
+	$parentRoleArrLen=php7_sizeof($parentRoleArr);
+	$immediateParent=$parentRoleArrLen>=2 ? $parentRoleArr[$parentRoleArrLen-2]:null;
 	$roleDet=Array();
 	$roleDet[]=$rolename;
 	$roleDet[]=$parentrole;
@@ -1236,7 +1237,7 @@ function deleteRoleRelatedSharingRules($roleId)
 				$colNameArr=explode('::',$colname);
 				$query="select shareid from ".$tablename." where ".$colNameArr[0]."=?";
 				$params = array($roleId);
-				if(sizeof($colNameArr) >1)
+				if(php7_sizeof($colNameArr) >1)
 				{
 						$query .=" or ".$colNameArr[1]."=?";
 						array_push($params, $roleId);
@@ -1275,7 +1276,7 @@ function deleteGroupRelatedSharingRules($grpId)
 				$colNameArr=explode('::',$colname);
 				$query="select shareid from ".$tablename." where ".$colNameArr[0]."=?";
 				$params = array($grpId);
-				if(sizeof($colNameArr) >1)
+				if(php7_sizeof($colNameArr) >1)
 				{
 						$query .=" or ".$colNameArr[1]."=?";
 						array_push($params, $grpId);
@@ -1455,11 +1456,14 @@ function getCombinedUserGlobalPermissions($userId)
 	$log->debug("Entering getCombinedUserGlobalPermissions(".$userId.") method ...");
 	global $adb;
 	$profArr=getUserProfile($userId);
-	$no_of_profiles=sizeof($profArr);
+	$no_of_profiles=php7_sizeof($profArr);
 	$userGlobalPerrArr=Array();
 
-	$userGlobalPerrArr=getProfileGlobalPermission($profArr[0]);
-	if($no_of_profiles != 1)
+	if($no_of_profiles) {
+		$userGlobalPerrArr=getProfileGlobalPermission($profArr[0]);
+	}
+	
+	if($no_of_profiles > 1)
 	{
 			for($i=1;$i<$no_of_profiles;$i++)
 		{
@@ -1501,7 +1505,7 @@ function getCombinedUserTabsPermissions($userId)
 	$log->debug("Entering getCombinedUserTabsPermissions(".$userId.") method ...");
 	global $adb;
 	$profArr=getUserProfile($userId);
-	$no_of_profiles=sizeof($profArr);
+	$no_of_profiles=php7_sizeof($profArr);
 	$userTabPerrArr=Array();
 
 	$userTabPerrArr=getProfileTabsPermission($profArr[0]);
@@ -1546,7 +1550,7 @@ function getCombinedUserActionPermissions($userId)
 	$log->debug("Entering getCombinedUserActionPermissions(".$userId.") method ...");
 	global $adb;
 	$profArr=getUserProfile($userId);
-	$no_of_profiles=sizeof($profArr);
+	$no_of_profiles=php7_sizeof($profArr);
 	$actionPerrArr=Array();
 
 	$actionPerrArr=getProfileAllActionPermission($profArr[0]);
@@ -1593,7 +1597,7 @@ function getParentRole($roleId)
 	$log->debug("Entering getParentRole(".$roleId.") method ...");
 	$roleInfo=getRoleInformation($roleId);
 	$parentRole=$roleInfo[$roleId][1];
-	$tempParentRoleArr=explode('::',$parentRole);
+	$tempParentRoleArr=explode('::',$parentRole?$parentRole:'');
 	$parentRoleArr=Array();
 	foreach($tempParentRoleArr as $role_id)
 	{
@@ -1702,7 +1706,7 @@ function getCurrentUserGroupList($userid = false) {
 
 	require('user_privileges/user_privileges_' . $userid . '.php');
 	$grpList = array();
-	if (sizeof($current_user_groups) > 0) {
+	if (php7_sizeof($current_user_groups) > 0) {
 		$i = 0;
 		foreach ($current_user_groups as $grpid) {
 			array_push($grpList, $grpid);
@@ -1739,7 +1743,7 @@ function constructList($array,$data_type)
 	global $log;
 	$log->debug("Entering constructList(".$array.",".$data_type.") method ...");
 	$list= array();
-	if(sizeof($array) > 0)
+	if(php7_sizeof($array) > 0)
 	{
 		$i=0;
 		foreach($array as $value)
@@ -1780,7 +1784,7 @@ function getListViewSecurityParameter($module)
 						or vtiger_crmentity.smownerid in(select shareduserid from vtiger_tmp_read_user_sharing_per where userid=".$current_user->id." and tabid=".$tabid.")
 						or (";
 
-						if(sizeof($current_user_groups) > 0)
+						if(php7_sizeof($current_user_groups) > 0)
 						{
 							  $sec_query .= " vtiger_groups.groupid in (". implode(",", $current_user_groups) .") or ";
 						}
@@ -1792,7 +1796,7 @@ function getListViewSecurityParameter($module)
 				"or vtiger_crmentity.smownerid in(select vtiger_user2role.userid from vtiger_user2role inner join vtiger_users on vtiger_users.id=vtiger_user2role.userid inner join vtiger_role on vtiger_role.roleid=vtiger_user2role.roleid where vtiger_role.parentrole like '".$current_user_parent_role_seq."::%') " .
 				"or vtiger_crmentity.smownerid in(select shareduserid from vtiger_tmp_read_user_sharing_per where userid=".$current_user->id." and tabid=".$tabid.") or (";
 
-				if(sizeof($current_user_groups) > 0)
+				if(php7_sizeof($current_user_groups) > 0)
 				{
 					$sec_query .= " vtiger_groups.groupid in (". implode(",", $current_user_groups) .") or ";
 				}
@@ -1805,7 +1809,7 @@ function getListViewSecurityParameter($module)
 				"or vtiger_crmentity.smownerid in(select vtiger_user2role.userid from vtiger_user2role inner join vtiger_users on vtiger_users.id=vtiger_user2role.userid inner join vtiger_role on vtiger_role.roleid=vtiger_user2role.roleid where vtiger_role.parentrole like '".$current_user_parent_role_seq."::%') " .
 				"or vtiger_crmentity.smownerid in(select shareduserid from vtiger_tmp_read_user_sharing_per where userid=".$current_user->id." and tabid=".$tabid.") or (";
 
-				if(sizeof($current_user_groups) > 0)
+				if(php7_sizeof($current_user_groups) > 0)
 				{
 					$sec_query .= " vtiger_groups.groupid in (". implode(",", $current_user_groups) .") or ";
 				}
@@ -1820,7 +1824,7 @@ function getListViewSecurityParameter($module)
 
 		$sec_query .= " or (";
 
-		if(sizeof($current_user_groups) > 0)
+		if(php7_sizeof($current_user_groups) > 0)
 		{
 			$sec_query .= " vtiger_groups.groupid in (". implode(",", $current_user_groups) .") or ";
 		}
@@ -1832,7 +1836,7 @@ function getListViewSecurityParameter($module)
 		$sec_query .= " and (vtiger_crmentity.smownerid in($current_user->id) or vtiger_crmentity.smownerid in(select vtiger_user2role.userid from vtiger_user2role inner join vtiger_users on vtiger_users.id=vtiger_user2role.userid inner join vtiger_role on vtiger_role.roleid=vtiger_user2role.roleid where vtiger_role.parentrole like '".$current_user_parent_role_seq."::%') or vtiger_crmentity.smownerid in(select shareduserid from vtiger_tmp_read_user_sharing_per where userid=".$current_user->id." and tabid=".$tabid.") ";
 
 		$sec_query .= " or (";
-				if(sizeof($current_user_groups) > 0)
+				if(php7_sizeof($current_user_groups) > 0)
 				{
 					$sec_query .= " vtiger_groups.groupid in (". implode(",", $current_user_groups) .") or ";
 				}
@@ -1854,7 +1858,7 @@ function getListViewSecurityParameter($module)
 			$condition = null;
 		$sec_query .= " and (vtiger_crmentity.smownerid in($current_user->id) $condition or vtiger_crmentity.smownerid in(select vtiger_user2role.userid from vtiger_user2role inner join vtiger_users on vtiger_users.id=vtiger_user2role.userid inner join vtiger_role on vtiger_role.roleid=vtiger_user2role.roleid where vtiger_role.parentrole like '".$current_user_parent_role_seq."::%')";
 
-		if(sizeof($current_user_groups) > 0)
+		if(php7_sizeof($current_user_groups) > 0)
 		{
 			$sec_query .= " or ((vtiger_groups.groupid in (". implode(",", $current_user_groups) .")))";
 		}
@@ -1867,7 +1871,7 @@ function getListViewSecurityParameter($module)
 		//Adding crteria for group sharing
 		 $sec_query .= " or ((";
 
-				if(sizeof($current_user_groups) > 0)
+				if(php7_sizeof($current_user_groups) > 0)
 				{
 					$sec_query .= " vtiger_groups.groupid in (". implode(",", $current_user_groups) .") or ";
 				}
@@ -1878,7 +1882,7 @@ function getListViewSecurityParameter($module)
 	{
 		$sec_query .= " and (vtiger_crmentity.smownerid in($current_user->id) or vtiger_crmentity.smownerid in(select vtiger_user2role.userid from vtiger_user2role inner join vtiger_users on vtiger_users.id=vtiger_user2role.userid inner join vtiger_role on vtiger_role.roleid=vtiger_user2role.roleid where vtiger_role.parentrole like '".$current_user_parent_role_seq."::%') or vtiger_crmentity.smownerid in(select shareduserid from vtiger_tmp_read_user_sharing_per where userid=".$current_user->id." and tabid=".$tabid.") or (";
 
-				if(sizeof($current_user_groups) > 0)
+				if(php7_sizeof($current_user_groups) > 0)
 				{
 					$sec_query .= " vtiger_groups.groupid in (". implode(",", $current_user_groups) .") or ";
 				}
@@ -1892,7 +1896,7 @@ function getListViewSecurityParameter($module)
 		//Adding crteria for group sharing
 		 $sec_query .= " or (";
 
-				if(sizeof($current_user_groups) > 0)
+				if(php7_sizeof($current_user_groups) > 0)
 				{
 					$sec_query .= " vtiger_groups.groupid in (". implode(",", $current_user_groups) .") or ";
 				}
@@ -1906,7 +1910,7 @@ function getListViewSecurityParameter($module)
 		//Adding crteria for group sharing
 		 $sec_query .= " or ((";
 
-				if(sizeof($current_user_groups) > 0)
+				if(php7_sizeof($current_user_groups) > 0)
 				{
 					$sec_query .= " vtiger_groups.groupid in (". implode(",", $current_user_groups) .") or ";
 				}
@@ -1918,7 +1922,7 @@ function getListViewSecurityParameter($module)
 
 		$sec_query .= " and (vtiger_crmentity.smownerid in($current_user->id) or vtiger_crmentity.smownerid in(select vtiger_user2role.userid from vtiger_user2role inner join vtiger_users on vtiger_users.id=vtiger_user2role.userid inner join vtiger_role on vtiger_role.roleid=vtiger_user2role.roleid where vtiger_role.parentrole like '".$current_user_parent_role_seq."::%') or vtiger_crmentity.smownerid in(select shareduserid from vtiger_tmp_read_user_sharing_per where userid=".$current_user->id." and tabid=".$tabid.") or ((";
 
-		if(sizeof($current_user_groups) > 0)
+		if(php7_sizeof($current_user_groups) > 0)
 		{
 			$sec_query .= " vtiger_groups.groupid in (". implode(",", $current_user_groups) .") or ";
 		}
@@ -1931,7 +1935,7 @@ function getListViewSecurityParameter($module)
 	{
 		$sec_query .= " and (vtiger_crmentity.smownerid in($current_user->id) or vtiger_crmentity.smownerid in(select vtiger_user2role.userid from vtiger_user2role inner join vtiger_users on vtiger_users.id=vtiger_user2role.userid inner join vtiger_role on vtiger_role.roleid=vtiger_user2role.roleid where vtiger_role.parentrole like '".$current_user_parent_role_seq."::%') or vtiger_crmentity.smownerid in(select shareduserid from vtiger_tmp_read_user_sharing_per where userid=".$current_user->id." and tabid=".$tabid.") or ((";
 
-				if(sizeof($current_user_groups) > 0)
+				if(php7_sizeof($current_user_groups) > 0)
 				{
 					$sec_query .= " vtiger_groups.groupid in (". implode(",", $current_user_groups) .") or ";
 				}
@@ -1947,7 +1951,7 @@ function getListViewSecurityParameter($module)
 
 		$sec_query .= " or (";
 
-		if(sizeof($current_user_groups) > 0)
+		if(php7_sizeof($current_user_groups) > 0)
 		{
 			$sec_query .= " vtiger_groups.groupid in (". implode(",", $current_user_groups) .") or ";
 		}
@@ -2128,7 +2132,7 @@ function getPermittedModuleNames()
 	{
 		foreach($tab_seq_array as $tabid=>$seq_value)
 		{
-			if($seq_value === 0 && $profileTabsPermission[$tabid] === 0)
+			if($seq_value === 0 && (isset($profileTabsPermission[$tabid]) && $profileTabsPermission[$tabid]) === 0)
 			{
 				$permittedModules[]=getTabModuleName($tabid);
 			}
@@ -2167,7 +2171,7 @@ function getPermittedModuleIdList() {
 	if($is_admin == false && $profileGlobalPermission[1] == 1 &&
 			$profileGlobalPermission[2] == 1) {
 		foreach($tab_seq_array as $tabid=>$seq_value) {
-			if($seq_value === 0 && $profileTabsPermission[$tabid] === 0) {
+			if($seq_value === 0 && isset($profileTabsPermission[$tabid]) && $profileTabsPermission[$tabid] === 0) {
 				$permittedModules[]=($tabid);
 			}
 		}
@@ -2319,4 +2323,4 @@ function appendFromClauseToQuery($query,$fromClause) {
 	return $query;
 }
 
-?>
\ No newline at end of file
+?>
