@@ -157,7 +157,7 @@ class Vtiger_Field_Model extends Vtiger_Field {
 
 	public function getModule() {
 		if(!isset($this->module) || !$this->module) {
-			$moduleObj = $this->block->module;
+			$moduleObj = isset($this->block->module) ? $this->block->module : "";
 			if(empty($moduleObj)) {
 				return false;
 			}
@@ -404,6 +404,7 @@ class Vtiger_Field_Model extends Vtiger_Field {
 	 * @return <Boolean> - true/false
 	 */
 	public function isMandatory() {
+		if(substr_count($this->get('typeofdata'),'~') == 0)  $this->set('typeofdata', $this->get('typeofdata') . '~');
 		list($type,$mandatory)= explode('~',$this->get('typeofdata'));
 		return $mandatory=='M' ? true:false;
 	}
@@ -520,7 +521,7 @@ class Vtiger_Field_Model extends Vtiger_Field {
 	public function isAjaxEditable() {
 	    $ajaxRestrictedFields = array(
 	        self::UITYPE_RECORD_NO, 
-	        self::UITYPE_CURRENCY_AMOUNT, 
+	        self::UITYPE_LINEITEMS_CURRENCY_AMOUNT, 
 	        self::UITYPE_ATTACHMENT, 
 	        self::UITYPE_DOWNLOAD_TYPE,
 	        self::UITYPE_FILENAME
@@ -722,7 +723,14 @@ class Vtiger_Field_Model extends Vtiger_Field {
 		}
 
 		if($this->getFieldDataType() == 'reference') {
-			$this->fieldInfo['referencemodules'] = $this->getReferenceList();
+				$this->fieldInfo['referencemodules'] = $this->getReferenceList();
+
+				// special case handling for (last-modified-by) which is reference of Users module.
+				if (count($this->fieldInfo['referencemodules']) == 1 && $this->fieldInfo['referencemodules'][0] == "Users") {
+						$picklistValues = array();
+						$picklistValues[vtranslate('LBL_USERS', $this->getModuleName())] = $currentUser->getAccessibleUsers();
+						$this->fieldInfo['picklistvalues'] = $picklistValues;
+				}
 		}
 
 		$this->fieldInfo['validator'] = $this->getValidator();
@@ -785,6 +793,7 @@ class Vtiger_Field_Model extends Vtiger_Field {
 		$nextweek1 = date("Y-m-d", strtotime("+1 week $prvDay"));
 
 		$next7days = date("Y-m-d", mktime(0, 0, 0, $m, $d + 6, $y));
+		$next14days = date("Y-m-d", mktime(0, 0, 0, $m, $d + 13, $y));
 		$next30days = date("Y-m-d", mktime(0, 0, 0, $m, $d + 29, $y));
 		$next60days = date("Y-m-d", mktime(0, 0, 0, $m, $d + 59, $y));
 		$next90days = date("Y-m-d", mktime(0, 0, 0, $m, $d + 89, $y));
@@ -865,6 +874,9 @@ class Vtiger_Field_Model extends Vtiger_Field {
 		} elseif ($type == "next7days") {
 			$dateValues[0] = $today;
 			$dateValues[1] = $next7days;
+		} elseif ($type == "next14days") {
+			$dateValues[0] = $today;
+			$dateValues[1] = $next14days;
 		} elseif ($type == "next30days") {
 			$dateValues[0] = $today;
 			$dateValues[1] = $next30days;
@@ -954,10 +966,13 @@ class Vtiger_Field_Model extends Vtiger_Field {
 								'last60days' => array('label' => 'LBL_LAST_60_DAYS'),
 								'last90days' => array('label' => 'LBL_LAST_90_DAYS'),
 								'last120days' => array('label' => 'LBL_LAST_120_DAYS'),
+								'next7days' => array('label' => 'LBL_NEXT_7_DAYS'),
+								'next14days' => array('label' => 'LBL_NEXT_14_DAYS'),
 								'next30days' => array('label' => 'LBL_NEXT_30_DAYS'),
 								'next60days' => array('label' => 'LBL_NEXT_60_DAYS'),
 								'next90days' => array('label' => 'LBL_NEXT_90_DAYS'),
-								'next120days' => array('label' => 'LBL_NEXT_120_DAYS')
+								'next120days' => array('label' => 'LBL_NEXT_120_DAYS'),
+								
 							);
 		$currentUserModel = Users_Record_Model::getCurrentUserModel();
 		$userPeferredDayOfTheWeek = $currentUserModel->get('dayoftheweek');
@@ -1333,7 +1348,7 @@ class Vtiger_Field_Model extends Vtiger_Field {
 	}
 
 	public function hasDefaultValue() {
-		return trim($this->defaultvalue) == '' ? false : true;
+		return !$this->defaultvalue || trim($this->defaultvalue) == '' ? false : true;
 	}
 
 	public function isActiveField() {
