@@ -518,6 +518,7 @@ class Vtiger_Module_Model extends Vtiger_Module {
 
 		$nameFieldObject = Vtiger_Cache::get('EntityField',$this->getName());
 		$moduleName = $this->getName();
+		$fieldNames = '';
 		if($nameFieldObject && $nameFieldObject->fieldname) {
 			$this->nameFields = explode(',', $nameFieldObject->fieldname);
 		} else {
@@ -526,6 +527,7 @@ class Vtiger_Module_Model extends Vtiger_Module {
 			$query = "SELECT fieldname, tablename, entityidfield FROM vtiger_entityname WHERE tabid = ?";
 			$result = $adb->pquery($query, array($this->getId()));
 			$this->nameFields = array();
+			$fieldNames = '';
 			if($result){
 				$rowCount = $adb->num_rows($result);
 				if($rowCount > 0){
@@ -1229,6 +1231,7 @@ class Vtiger_Module_Model extends Vtiger_Module {
 	public function getOwnerWhereConditionForDashBoards ($owner) {
 		$currentUserModel = Users_Record_Model::getCurrentUserModel();
 		$sharingAccessModel = Settings_SharingAccess_Module_Model::getInstance($this->getName());
+		$ownerSql = '';
 		$params = array();
 		if(!empty($owner) && $currentUserModel->isAdminUser()) {//If admin user, then allow users data
 			$ownerSql =  ' smownerid = '. $owner;
@@ -1622,6 +1625,7 @@ class Vtiger_Module_Model extends Vtiger_Module {
         if(empty($relationIds))  return array();
         
 		$focus = CRMEntity::getInstance($this->getName());
+		$focus->related_module_table_index=isset($focus->related_module_table_index) ? $focus->related_module_table_index : null;
 		$relatedModuleMapping = $focus->related_module_table_index;
         
         $relationFieldMapping = array();
@@ -1655,9 +1659,9 @@ class Vtiger_Module_Model extends Vtiger_Module {
                 
                 
                 if(empty($relationFieldId)){
-                    $tablename = $relatedModuleMapping[$module]['table_name'];
-                    $tabIndex = $relatedModuleMapping[$module]['table_index'];
-                    $relIndex = $relatedModuleMapping[$module]['rel_index'];
+                    $tablename = isset($relatedModuleMapping[$module]['table_name']) ? $relatedModuleMapping[$module]['table_name'] : '';
+                    $tabIndex = isset($relatedModuleMapping[$module]['table_index']) ? $relatedModuleMapping[$module]['table_index'] : '';
+                    $relIndex = isset($relatedModuleMapping[$module]['rel_index']) ? $relatedModuleMapping[$module]['rel_index'] : '';
 					//To show related records comments in documents, should get related document records from vtiger_senotesrel.
 					if(empty($tablename) && $this->getName() == 'Documents') {
 						$tablename = 'vtiger_senotesrel';
