@@ -174,7 +174,7 @@ class Vtiger_ComposeEmail_View extends Vtiger_Footer_View {
 			foreach($selectIds as $id) { 
 				  if ($id) { 
 						$parentIdComponents = explode('@', $id); 
-						if (count($parentIdComponents) > 1) { 
+						if (php7_count($parentIdComponents) > 1) { 
 								$id = $parentIdComponents[0]; 
 								if ($parentIdComponents[1] === '-1') { 
 										$recordModel = Users_Record_Model::getInstanceById($id, 'Users'); 
@@ -237,7 +237,7 @@ class Vtiger_ComposeEmail_View extends Vtiger_Footer_View {
 		$viewer = $this->getViewer($request);
 		$attachment = array();
 
-		if(!$this->record) {
+		if(!property_exists($this, 'record') || !$this->record) {
 			$this->record = Vtiger_DetailView_Model::getInstance($moduleName, $recordId);
 		}
 		$recordModel = $this->record->getRecord();
@@ -255,6 +255,7 @@ class Vtiger_ComposeEmail_View extends Vtiger_Footer_View {
 	}
 
 	public function process(Vtiger_Request $request) {
+		$moduleName = $request->getModule();
 		$mode = $request->getMode();
 		if(!empty($mode)) {
 			echo $this->invokeExposedMethod($mode, $request);
@@ -269,7 +270,8 @@ class Vtiger_ComposeEmail_View extends Vtiger_Footer_View {
 		return;
 	}
 
-	public function getRecordsListFromRequest(Vtiger_Request $request) {
+	public function getRecordsListFromRequest(Vtiger_Request $request, $model = false) {
+		$moduleName = $request->getModule();
 		$cvId = $request->get('viewname');
 		$selectedIds = $request->get('selected_ids');
 		$excludedIds = $request->get('excluded_ids');
@@ -296,7 +298,7 @@ class Vtiger_ComposeEmail_View extends Vtiger_Footer_View {
         }
 
 		if(!empty($selectedIds) && $selectedIds != 'all') {
-			if(!empty($selectedIds) && count($selectedIds) > 0) {
+			if(!empty($selectedIds) && php7_count($selectedIds) > 0) {
 				return $selectedIds;
 			}
 		}
@@ -415,7 +417,7 @@ class Vtiger_ComposeEmail_View extends Vtiger_Footer_View {
 	function emailEdit($request){
 		$viewer = $this->getViewer($request);
 		$this->emailActionsData($request);
-
+		$parentRecordModel = null;
 		$recordId = $request->get('record');
 		$moduleName = $request->getModule();
 		$viewer = $this->getViewer($request);
@@ -429,6 +431,9 @@ class Vtiger_ComposeEmail_View extends Vtiger_Footer_View {
 		$CC = Zend_Json::decode(html_entity_decode($recordModel->get('ccmail')));
 		$BCC = Zend_Json::decode(html_entity_decode($recordModel->get('bccmail')));
 
+		// Under Condition CC & BCC fields are empty .. 
+		$CC = is_array($CC) ? $CC : array();
+		$BCC = is_array($BCC) ? $BCC : array();
 		$parentIds = explode('|',$recordModel->get('parent_id'));
 
 		$toMailInfo = $toMailNamesList = array();
