@@ -417,6 +417,8 @@ $languageStrings = array(
 	'LBL_LAST_60_DAYS' => 'Last 60 Days',
 	'LBL_LAST_90_DAYS' => 'Last 90 Days',
 	'LBL_LAST_120_DAYS' => 'Last 120 Days',
+	'LBL_NEXT_7_DAYS' => 'Next 7 Days',
+	'LBL_NEXT_14_DAYS' => 'Next 14 Days',
 	'LBL_NEXT_30_DAYS' => 'Next 30 Days',
 	'LBL_NEXT_60_DAYS' => 'Next 60 Days',
 	'LBL_NEXT_90_DAYS' => 'Next 90 Days',
@@ -840,7 +842,7 @@ $languageStrings = array(
     
     // SMSNotifier Phone Format Warning
     'LBL_PHONE_FORMAT_WARNING' => 'يرجى التأكد من رقم الهاتف في تنسيق E.164 الدولية',
-    'LBL_PHONEFORMAT_WARNING_CONTENT' => 'عدد E.164 التنسيق يمكن أن يكون بحد أقصى خمسة عشر رقما وعادة ما تكون مكتوبة على النحو التالي: [+] [رمز البلد] [رقم المشترك بما في ذلك رمز المنطقة]  على سبيل المثال، لتحويل رقم هاتف الولايات المتحدة (415 599 2671) إلى تنسيق E.164، فإن المرء بحاجة إلى إضافة البادئة '+' ورمز البلد (والذي هو 1) أمام الرقم (+1 415 599 2671 ). في المملكة المتحدة والعديد من البلدان الأخرى على الصعيد الدولي، والاتصال المحلية يتطلب إضافة 0 أمام عدد المشتركين. ومع ذلك، لاستخدام التنسيق E.164، يجب إزالة هذا 0. سيتم تنسيق عدد مثل 020 7183 8750 في المملكة المتحدة و+44 20 7183 8750.',
+    'LBL_PHONEFORMAT_WARNING_CONTENT' => 'عدد E.164 التنسيق يمكن أن يكون بحد أقصى خمسة عشر رقما وعادة ما تكون مكتوبة على النحو التالي: [+] [رمز البلد] [رقم المشترك بما في ذلك رمز المنطقة]  على سبيل المثال، لتحويل رقم هاتف الولايات المتحدة (415 599 2671) إلى تنسيق E.164، فإن المرء بحاجة إلى إضافة البادئة ورمز البلد (والذي هو 1) أمام الرقم (+1 415 599 2671 ). في المملكة المتحدة والعديد من البلدان الأخرى على الصعيد الدولي، والاتصال المحلية يتطلب إضافة 0 أمام عدد المشتركين. ومع ذلك، لاستخدام التنسيق E.164، يجب إزالة هذا 0. سيتم تنسيق عدد مثل 020 7183 8750 في المملكة المتحدة و+44 20 7183 8750.',
     'LBL_WARNING' => 'تحذير',
 	'LBL_SEND_PDF_FOR_SIGNING' => 'إرسال PDF للتوقيع',
 	'LBL_INCLUDE_SIGNATURE_INFO' => 'سيتم إلحاق التوقيع المنصوص عليها في بلدي تفضيلات إلى الجزء السفلي من البريد الإلكتروني',
@@ -1140,6 +1142,7 @@ Vtiger الاتصالات جوجل اتصالات(مجموعة مختارة مح
   'LBL_MARKETING' => 'التسويق',
   'LBL_SALES' => 'المبيعات',
   'LBL_PROJECT' => 'المشاريع',
+	'LBL_TOOLS' => 'أدوات',
   'LBL_TAGS' => 'Tags',
   'LBL_SHARE_TAGS' => 'الجمهور العلامات',
   'LBL_SHARE_TAG' => 'حصة العلامة',
@@ -1458,7 +1461,7 @@ $jsLanguageStrings = array(
     'JS_PLEASE_SELECT_A_FILE' => 'الرجاء اختيار ملف',
     
     // SMSNotifier Phone Format Warning
-    'JS_PHONEFORMAT_ERROR' => 'يرجى التحقق من رقم الهاتف في تنسيق E.164 INTERNATONAL مع '+' بادئة ورمز البلد تحويلة +1 415 2671 599',
+    'JS_PHONEFORMAT_ERROR' => 'يرجى التحقق من رقم الهاتف في تنسيق E.164 INTERNATONAL مع بادئة ورمز البلد تحويلة +1 415 2671 599',
     
     // Lead and Potential Mapping Fields
     'JS_NONE' => 'None',
@@ -1692,4 +1695,5 @@ $jsLanguageStrings = array(
 	'JS_DUPLICATES_DETECTED' => 'تكرار (ق) الكشف عن!',
 	'JS_PASSWORD_MISMATCH_ERROR' => 'يرجى إعادة إدخال كلمة السر. "كلمة السر الجديدة" و "كلمة السر تأكيد" عدم تطابق القيم.',
 	'JS_LIST_DELETE_CONFIRMATION' => 'هل أنت متأكد أنك تريد حذف؟',
-);
\ No newline at end of file
+	'JS_WIDGET_RESIZING_WAIT_MSG' => 'سيتم تحميل محتويات القطعة بعد تغيير الحجم.',
+);
