@@ -16,7 +16,7 @@ class Vtiger_AccessControl {
 		'current_user_groups', 'subordinate_roles', 'parent_roles', 'subordinate_roles_users', 'user_info'
 	);
 
-	protected function __consturct() {
+	protected function __construct() {
 		$this->privileges = array();
 	}
 
@@ -49,7 +49,7 @@ class Vtiger_AccessControl {
 			self::$singleton = new self();
 		}
 
-		if (self::$singleton->privileges && self::$singleton->privileges[$id]) {
+		if ( self::$singleton->privileges ) {
 			unset(self::$singleton->privileges[$id]);
 		}
 	}
